import { homedir } from 'os';
import { join } from 'path';
import { cosmiconfigSync } from 'cosmiconfig';
/**
 * @internal
 */
function isSupportedProduct(product) {
    switch (product) {
        case 'chrome':
        case 'firefox':
            return true;
        default:
            return false;
    }
}
/**
 * @internal
 */
export const getConfiguration = () => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9;
    const result = cosmiconfigSync('puppeteer').search();
    const configuration = result ? result.config : {};
    configuration.logLevel = ((_d = (_c = (_b = (_a = process.env['PUPPETEER_LOGLEVEL']) !== null && _a !== void 0 ? _a : process.env['npm_config_LOGLEVEL']) !== null && _b !== void 0 ? _b : process.env['npm_package_config_LOGLEVEL']) !== null && _c !== void 0 ? _c : configuration.logLevel) !== null && _d !== void 0 ? _d : 'warn');
    // Merging environment variables.
    configuration.defaultProduct = ((_h = (_g = (_f = (_e = process.env['PUPPETEER_PRODUCT']) !== null && _e !== void 0 ? _e : process.env['npm_config_puppeteer_product']) !== null && _f !== void 0 ? _f : process.env['npm_package_config_puppeteer_product']) !== null && _g !== void 0 ? _g : configuration.defaultProduct) !== null && _h !== void 0 ? _h : 'chrome');
    configuration.executablePath =
        (_l = (_k = (_j = process.env['PUPPETEER_EXECUTABLE_PATH']) !== null && _j !== void 0 ? _j : process.env['npm_config_puppeteer_executable_path']) !== null && _k !== void 0 ? _k : process.env['npm_package_config_puppeteer_executable_path']) !== null && _l !== void 0 ? _l : configuration.executablePath;
    // Default to skipDownload if executablePath is set
    if (configuration.executablePath) {
        configuration.skipDownload = true;
    }
    // Set skipDownload explicitly or from default
    configuration.skipDownload = Boolean((_p = (_o = (_m = process.env['PUPPETEER_SKIP_DOWNLOAD']) !== null && _m !== void 0 ? _m : process.env['npm_config_puppeteer_skip_download']) !== null && _o !== void 0 ? _o : process.env['npm_package_config_puppeteer_skip_download']) !== null && _p !== void 0 ? _p : configuration.skipDownload);
    // Prepare variables used in browser downloading
    if (!configuration.skipDownload) {
        configuration.browserRevision =
            (_s = (_r = (_q = process.env['PUPPETEER_BROWSER_REVISION']) !== null && _q !== void 0 ? _q : process.env['npm_config_puppeteer_browser_revision']) !== null && _r !== void 0 ? _r : process.env['npm_package_config_puppeteer_browser_revision']) !== null && _s !== void 0 ? _s : configuration.browserRevision;
        const downloadHost = (_u = (_t = process.env['PUPPETEER_DOWNLOAD_HOST']) !== null && _t !== void 0 ? _t : process.env['npm_config_puppeteer_download_host']) !== null && _u !== void 0 ? _u : process.env['npm_package_config_puppeteer_download_host'];
        if (downloadHost && configuration.logLevel === 'warn') {
            console.warn(`PUPPETEER_DOWNLOAD_HOST is deprecated. Use PUPPETEER_DOWNLOAD_BASE_URL instead.`);
        }
        configuration.downloadBaseUrl =
            (_y = (_x = (_w = (_v = process.env['PUPPETEER_DOWNLOAD_BASE_URL']) !== null && _v !== void 0 ? _v : process.env['npm_config_puppeteer_download_base_url']) !== null && _w !== void 0 ? _w : process.env['npm_package_config_puppeteer_download_base_url']) !== null && _x !== void 0 ? _x : configuration.downloadBaseUrl) !== null && _y !== void 0 ? _y : downloadHost;
        configuration.downloadPath =
            (_1 = (_0 = (_z = process.env['PUPPETEER_DOWNLOAD_PATH']) !== null && _z !== void 0 ? _z : process.env['npm_config_puppeteer_download_path']) !== null && _0 !== void 0 ? _0 : process.env['npm_package_config_puppeteer_download_path']) !== null && _1 !== void 0 ? _1 : configuration.downloadPath;
    }
    configuration.cacheDirectory =
        (_5 = (_4 = (_3 = (_2 = process.env['PUPPETEER_CACHE_DIR']) !== null && _2 !== void 0 ? _2 : process.env['npm_config_puppeteer_cache_dir']) !== null && _3 !== void 0 ? _3 : process.env['npm_package_config_puppeteer_cache_dir']) !== null && _4 !== void 0 ? _4 : configuration.cacheDirectory) !== null && _5 !== void 0 ? _5 : join(homedir(), '.cache', 'puppeteer');
    configuration.temporaryDirectory =
        (_8 = (_7 = (_6 = process.env['PUPPETEER_TMP_DIR']) !== null && _6 !== void 0 ? _6 : process.env['npm_config_puppeteer_tmp_dir']) !== null && _7 !== void 0 ? _7 : process.env['npm_package_config_puppeteer_tmp_dir']) !== null && _8 !== void 0 ? _8 : configuration.temporaryDirectory;
    (_9 = configuration.experiments) !== null && _9 !== void 0 ? _9 : (configuration.experiments = {});
    // Validate configuration.
    if (!isSupportedProduct(configuration.defaultProduct)) {
        throw new Error(`Unsupported product ${configuration.defaultProduct}`);
    }
    return configuration;
};
//# sourceMappingURL=getConfiguration.js.map